@@ -39,7 +39,7 @@
 #define SMALLTICKSIZE 4
 #define TICKOFFSET 0
 
-class KPlotWidget::Private
+class Q_DECL_HIDDEN KPlotWidget::Private
 {
 public:
     Private(KPlotWidget *qq)
@@ -386,13 +386,13 @@ void KPlotWidget::setObjectToolTipShown(bool show)
 KPlotAxis *KPlotWidget::axis(Axis type)
 {
     QHash<Axis, KPlotAxis *>::Iterator it = d->axes.find(type);
-    return it != d->axes.end() ? it.value() : 0;
+    return it != d->axes.end() ? it.value() : nullptr;
 }
 
 const KPlotAxis *KPlotWidget::axis(Axis type) const
 {
     QHash<Axis, KPlotAxis *>::ConstIterator it = d->axes.constFind(type);
-    return it != d->axes.constEnd() ? it.value() : 0;
+    return it != d->axes.constEnd() ? it.value() : nullptr;
 }
 
 QRect KPlotWidget::pixRect() const
@@ -420,7 +420,7 @@ bool KPlotWidget::event(QEvent *e)
         if (d->showObjectToolTip) {
             QHelpEvent *he = static_cast<QHelpEvent *>(e);
             QList<KPlotPoint *> pts = pointsUnderPoint(he->pos() - QPoint(leftPadding(), topPadding()) - contentsRect().topLeft());
-            if (pts.count() > 0) {
+            if (!pts.isEmpty()) {
                 QToolTip::showText(he->globalPos(), pts.front()->label(), this);
             }
         }
